[![Build Status](https://travis-ci.org/roxyboy/xomega.svg?branch=master)](https://travis-ci.org/roxyboy/xomega)
[![Documentation Status](https://readthedocs.org/projects/xomega/badge/?version=latest)](https://xomega.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/125751493.svg)](https://zenodo.org/badge/latestdoi/125751493)

# xomega: Inversion of the QG Omega equation
Functions to invert the [generalized Omega equation](https://journals.ametsoc.org/doi/full/10.1175/1520-0493%282000%29128%3C2270%3AMAAOAC%3E2.0.CO%3B2),
developed by [Takaya Uchida](https://roxyboy.github.io/), a Physical Oceanographer with interest in eddy tracer transport.
